@@ -35,6 +35,12 @@ def get_root_directory(level=logging.DEBUG):
     logger.info("Root directory found: " + root_directory)
     return root_directory
 
+def get_source_directory(sourceDirName):
+    root_dir = get_root_directory()
+    source_directory = __find_folder_in_current_or_above(sourceDirName, root_dir)
+
+    return source_directory
+
 def __find_folder_in_current_or_above(dirname, currentdir, level=logging.DEBUG):
     logger = logging.getLogger("logger")
     logger.setLevel(level)
